// Bristleback plugin - Copyright (c) 2010 bristleback.googlecode.com
// ---------------------------------------------------------------------------
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software Foundation; either version 3 of the License, or (at your
// option) any later version.
// This library is distributed in the hope that it will be useful,
// but without any warranty; without even the implied warranty of merchantability
// or fitness for a particular purpose.
// You should have received a copy of the GNU Lesser General Public License along
// with this program; if not, see <http://www.gnu.org/licenses/lgpl.html>.
// ---------------------------------------------------------------------------
package pl.bristleback.server.bristle.config;

import org.apache.log4j.Logger;

/**
 * Base Bristle JWebsocket Plugin constants.
 * Values of those constants are names of plugin settings, plugin token namespace and maybe more in future.
 * <p/>
 * Created on: 2010-10-04 17:21:29 <br/>
 *
 * @author Wojciech Niemiec
 */
public final class BristleConstants {
  private static Logger log = Logger.getLogger(BristleConstants.class.getName());

  private BristleConstants() {
    throw new UnsupportedOperationException();
  }

  /**
   * Bristle plugin namespace, used to indicate that token should be processed by Bristle plugin.
   */
  public static final String BRISTLE_PLUGIN_NAMESPACE = "bristlePlugin";

  /**
   * Configuration element name for those who wants to provide own {@link pl.bristleback.server.bristle.config.ActionAnnotationsProcessor} interface implementation.
   */
  public static final String ACTION_CLASS_RESOLVER_CLASS_PARAMETER_NAME = "actionClassResolver";

  /**
   * Element of token used for dispatching incoming messages. Every token has to contain this element.
   */
  public static final String ACTION_NAME_TOKEN_VARIABLE = "type"; //todo-wojtek search for constant in jwebsocket library

  /**
   * Configuration element name for those who wants to provide own {@link pl.bristleback.server.bristle.messages.MessageDispatcher} interface implementation.
   */
  public static final String DISPATCHER_CLASS_NAME_PARAMETER = "dispatcherClass";

  /**
   * Configuration element, prefix of message sender class setting.
   * Used in default implementation of {@link MessageContainerResolver} interface.
   * Every sender class is related with message sender name. Sender classes parameters should be counted from 0,
   * for example, second sender class should have parameter name: [MESSAGE_SENDER_CLASS_NAME_PARAMETER_PREFIX]1.
   */
  public static final String MESSAGE_SENDER_CLASS_NAME_PARAMETER_PREFIX = "messageSender_class_";

  /**
   * Configuration element, prefix of message sender Spring bean reference setting.
   * Used in default implementation of {@link MessageContainerResolver} interface.
   * Every sender class is related with message sender name.
   * Sender Spring beans should be suffixed with fallowing numbers, starting from 0.
   */
  public static final String MESSAGE_SENDER_SPRING_REF_PARAMETER_PREFIX = "messageSender_ref_";

  /**
   * Configuration element, prefix of message sender name setting.
   * Used in default implementation of {@link MessageContainerResolver} interface.
   * There can be multiple message senders used in the same time. Senders can be obtained in two ways,
   * by creating new instance of sender (message sender class name required)
   * or by retrieving Spring bean (message sender Spring bean reference required).
   */
  public static final String MESSAGE_SENDER_NAME_PARAMETER_PREFIX = "messageSender_name_";

  /**
   * Configuration element name for action package location definition.
   */
  public static final String ACTION_PACKAGE_SETTING_NAME = "actionPackage";

  /**
   * Configuration element name for those who wants to provide own {@link MessageContainerResolver} interface implementation.
   */
  public static final String MESSAGE_RESOLVER_CLASS_PARAMETER_NAME = "actionClassResolver";

  /**
   * Name of connector rights set token element created when connector is connecting.
   */
  public static final String CONNECTOR_RIGHTS_SET_VARIABLE_NAME = "bristleCRS";

  /**
   * Configuration element, prefix of server state listener name setting.
   * Used in {@link pl.bristleback.server.bristle.states.ServerStateInspector} class.
   * There can be multiple server state listeners used in the same time. Listeners can be obtained in two ways,
   * by creating new instance of listener (then class name is required)
   * or by retrieving Spring bean (Spring bean reference required).
   */
  public static final String SERVER_STATE_LISTENER_NAME_PARAMETER_PREFIX = "serverStateListener_name_";

  /**
   * Configuration element, prefix of server state listener class setting.
   * Used in {@link pl.bristleback.server.bristle.states.ServerStateInspector} class.
   * Every listener class is related with listener name. Listener classes parameters should be counted from 0,
   * for example, second server state listener class should have parameter name: [SERVER_STATE_LISTENER_CLASS_PARAMETER_PREFIX]1.
   */
  public static final String SERVER_STATE_LISTENER_CLASS_PARAMETER_PREFIX = "serverStateListener_class_";

  /**
   * Configuration element, prefix of server state listener Spring bean reference setting.
   * Used in {@link pl.bristleback.server.bristle.states.ServerStateInspector} class.
   * Every listener bean is related with listener name. Listener beans parameters should be counted from 0,
   * for example, second server state listener Spring bean should have parameter name: [SERVER_STATE_LISTENER_REF_PARAMETER_PREFIX]1.
   */
  public static final String SERVER_STATE_LISTENER_REF_PARAMETER_PREFIX = "serverStateListener_ref_";

  /**
   * This settings can be set as one of context parameter in 'web.xml' in web application.
   * It is a path of the jwebsocket configuration file.
   * If not set, configuration file will be searched in default locations, depending on jWebsocket library version.
   */
  public static final String CONFIG_FILE_LOCATION_CONTEXT_VARIABLE_NAME = "bristlePluginConfigurationFilename";

  /**
   * This settings can be set as one of context parameter in 'web.xml' in web application.
   * If set to 'true', Spring Framework integration will be enabled.
   */
  public static final String SPRING_INTEGRATION_CONTEXT_VARIABLE_NAME = "bristlePluginEnableSpring";
}
